pub trait ErrorType {
type Error: Error;
}Expand description
Base trait for all IO traits, defining the error type.
All IO operations of all traits return the error defined in this trait.
Having a shared trait instead of having every trait define its own
Error associated type enforces all impls on the same type use the same error.
This is very convenient when writing generic code, it means you have to
handle a single error type T::Error, instead of <T as Read>::Error and <T as Write>::Error
which might be different types.
Required Associated Types
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Implementors
Sourceimpl ErrorType for EspFirmwareInfoLoad
impl ErrorType for EspFirmwareInfoLoad
type Error = EspIOError
Sourceimpl ErrorType for EspFirmwareInfoLoader
impl ErrorType for EspFirmwareInfoLoader
type Error = EspIOError
Sourceimpl ErrorType for esp_idf_svc::http::client::EspHttpConnection
impl ErrorType for esp_idf_svc::http::client::EspHttpConnection
type Error = EspIOError
Sourceimpl ErrorType for esp_idf_svc::http::server::EspHttpConnection<'_>
impl ErrorType for esp_idf_svc::http::server::EspHttpConnection<'_>
type Error = EspIOError
Sourceimpl ErrorType for EspHttpRawConnection<'_>
impl ErrorType for EspHttpRawConnection<'_>
type Error = EspIOError
Sourceimpl ErrorType for EspOtaUpdate<'_>
impl ErrorType for EspOtaUpdate<'_>
type Error = EspIOError
Sourceimpl ErrorType for EspOtaUpdateFinished<'_>
impl ErrorType for EspOtaUpdateFinished<'_>
type Error = EspIOError
Sourceimpl ErrorType for UartDriver<'_>
impl ErrorType for UartDriver<'_>
type Error = EspIOError
Sourceimpl ErrorType for UartRxDriver<'_>
impl ErrorType for UartRxDriver<'_>
type Error = EspIOError
Sourceimpl ErrorType for UartTxDriver<'_>
impl ErrorType for UartTxDriver<'_>
type Error = EspIOError
Sourceimpl ErrorType for UsbSerialDriver<'_>
impl ErrorType for UsbSerialDriver<'_>
type Error = EspIOError
Sourceimpl<'d, T> ErrorType for AsyncUartDriver<'d, T>where
T: BorrowMut<UartDriver<'d>>,
impl<'d, T> ErrorType for AsyncUartDriver<'d, T>where
T: BorrowMut<UartDriver<'d>>,
type Error = EspIOError
Sourceimpl<'d, T> ErrorType for AsyncUartRxDriver<'d, T>where
T: BorrowMut<UartRxDriver<'d>>,
impl<'d, T> ErrorType for AsyncUartRxDriver<'d, T>where
T: BorrowMut<UartRxDriver<'d>>,
type Error = EspIOError
Sourceimpl<'d, T> ErrorType for AsyncUartTxDriver<'d, T>where
T: BorrowMut<UartTxDriver<'d>>,
impl<'d, T> ErrorType for AsyncUartTxDriver<'d, T>where
T: BorrowMut<UartTxDriver<'d>>,
type Error = EspIOError
Sourceimpl<S> ErrorType for EspAsyncTls<S>where
S: PollableSocket,
Available on non-esp_idf_version_major=4 and (non-esp_idf_version_major=5 or non-esp_idf_version_minor=0) only.
impl<S> ErrorType for EspAsyncTls<S>where
S: PollableSocket,
Available on non-
esp_idf_version_major=4 and (non-esp_idf_version_major=5 or non-esp_idf_version_minor=0) only.